===========================
 Number handling functions
===========================

.. _fluent-number:

Fluent.number
-------------

TODO!

.. _fluent-formattednumber:

Fluent.formattedNumber
----------------------

TODO!

Example of how it works is in the tests:

* https://github.com/elm-fluent/elm-fluent/blob/641a3bd889a95f165ff70348a321698455ce907d/tests/test_project/Main.elm#L154
* https://github.com/elm-fluent/elm-fluent/blob/641a3bd889a95f165ff70348a321698455ce907d/tests/test_project/Main.elm#L88
